@@ -356,6 +356,11 @@ class IncVersionTests(TestCase):
     def test_native(self):
         self.assertEqual(Version('1.1'), _inc_version(Version('1.0')))
         self.assertEqual(Version('1a1.1'), _inc_version(Version('1a1.0')))
+        self.assertEqual(Version('9.11~2'), _inc_version(Version('9.11~1')))
+        self.assertEqual(Version('9.11~1'), _inc_version(Version('9.11~')))
 
     def test_non_native(self):
         self.assertEqual(Version('1.1-2'), _inc_version(Version('1.1-1')))
+        self.assertEqual(Version('9.11-1~1'), _inc_version(Version('9.11-1~')))
+        self.assertEqual(
+            Version('9.11-1~2'), _inc_version(Version('9.11-1~1')))
