@@ -46,7 +46,6 @@ from lintian_brush import (
     UnsupportedCertainty,
     available_lintian_fixers,
     check_clean_tree,
-    add_changelog_entry,
     certainty_sufficient,
     min_certainty,
     certainty_to_confidence,
@@ -858,95 +857,3 @@ class SelectFixersTests(TestCase):
                 [DummyFixer('dummy1', 'some-tag'),
                  DummyFixer('dummy2', 'other-tag')],
                 ['dummy1', 'dummy2'], ['dummy2'])])
-
-
-class ChangelogAddEntryTests(TestCaseWithTransport):
-
-    def test_edit_existing(self):
-        tree = self.make_branch_and_tree('.')
-        self.build_tree_contents([
-            ('debian/', ),
-            ('debian/changelog', """\
-lintian-brush (0.35) UNRELEASED; urgency=medium
-
-  * Support updating templated debian/control files that use cdbs
-    template.
-
- -- Joe Example <joe@example.com>  Fri, 04 Oct 2019 02:36:13 +0000
- """)])
-        tree.add(['debian', 'debian/changelog'])
-        self.overrideEnv('DEBFULLNAME', 'Jane Example')
-        self.overrideEnv('DEBEMAIL', 'jane@example.com')
-        add_changelog_entry(tree, 'debian/changelog', 'Add a foo')
-        self.assertFileEqual("""\
-lintian-brush (0.35) UNRELEASED; urgency=medium
-
-  [ Joe Example ]
-  * Support updating templated debian/control files that use cdbs
-    template.
-
-  [ Jane Example ]
-  * Add a foo
-
- -- Joe Example <joe@example.com>  Fri, 04 Oct 2019 02:36:13 +0000
-""", 'debian/changelog')
-
-    def test_add_new(self):
-        tree = self.make_branch_and_tree('.')
-        self.build_tree_contents([
-            ('debian/', ),
-            ('debian/changelog', """\
-lintian-brush (0.35) unstable; urgency=medium
-
-  * Support updating templated debian/control files that use cdbs
-    template.
-
- -- Joe Example <joe@example.com>  Fri, 04 Oct 2019 02:36:13 +0000
- """)])
-        tree.add(['debian', 'debian/changelog'])
-        self.overrideEnv('DEBFULLNAME', 'Jane Example')
-        self.overrideEnv('DEBEMAIL', 'jane@example.com')
-        self.overrideEnv('DEBCHANGE_VENDOR', 'debian')
-        add_changelog_entry(tree, 'debian/changelog', 'Add a foo')
-        text = tree.get_file_text('debian/changelog').decode()
-        lines = text.splitlines()
-        self.assertEqual([
-            'lintian-brush (0.36) UNRELEASED; urgency=medium',
-            '',
-            '  * Add a foo',
-            ''],
-            lines[:4])
-        self.assertTrue(
-            lines[4].startswith(' -- Jane Example <jane@example.com>  '),
-            lines[4])
-
-    def test_edit_broken_first_line(self):
-        tree = self.make_branch_and_tree('.')
-        self.build_tree_contents([
-            ('debian/', ),
-            ('debian/changelog', """\
-THIS IS NOT A PARSEABLE LINE
-lintian-brush (0.35) UNRELEASED; urgency=medium
-
-  * Support updating templated debian/control files that use cdbs
-    template.
-
- -- Joe Example <joe@example.com>  Fri, 04 Oct 2019 02:36:13 +0000
- """)])
-        tree.add(['debian', 'debian/changelog'])
-        self.overrideEnv('DEBFULLNAME', 'Jane Example')
-        self.overrideEnv('DEBEMAIL', 'jane@example.com')
-        add_changelog_entry(tree, 'debian/changelog', 'Add a foo')
-        self.assertFileEqual("""\
-THIS IS NOT A PARSEABLE LINE
-lintian-brush (0.35) UNRELEASED; urgency=medium
-
-  [ Joe Example ]
-  * Support updating templated debian/control files that use cdbs
-    template.
-
-  [ Jane Example ]
-  * Add a foo
-
- -- Joe Example <joe@example.com>  Fri, 04 Oct 2019 02:36:13 +0000
-""", 'debian/changelog')
